# -*- coding: utf-8 -*-
from django.db import connections
from django.db import models
from south.db import db
from south.v2 import SchemaMigration


class Migration(SchemaMigration):

    def forwards(self, orm):
        # ---------------------------------------------------------------------
        # Изначально приложение было создано без миграций, поэтому могли
        # остаться таблицы, созданные при syncdb
        connection = connections[db.db_alias]
        table_names = connection.introspection.table_names()
        if (
            'rbac_permission' in table_names and
            'rbac_role' in table_names and
            db.shorten_name('rbac_role_permissions') in table_names and
            'rbac_roleparent' in table_names and
            'rbac_userrole' in table_names
        ):
            return
        # ---------------------------------------------------------------------

        # Adding model 'Permission'
        db.create_table('rbac_permission', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('name', self.gf('django.db.models.fields.CharField')(unique=True, max_length=100, db_index=True)),
            ('title', self.gf('django.db.models.fields.CharField')(max_length=200, unique=True, null=True, blank=True)),
            ('description', self.gf('django.db.models.fields.TextField')(blank=True)),
        ))
        db.send_create_signal('rbac', ['Permission'])

        # Adding model 'Role'
        db.create_table('rbac_role', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('name', self.gf('django.db.models.fields.CharField')(unique=True, max_length=300, db_index=True)),
            ('description', self.gf('django.db.models.fields.TextField')(blank=True)),
        ))
        db.send_create_signal('rbac', ['Role'])

        # Adding M2M table for field permissions on 'Role'
        m2m_table_name = db.shorten_name('rbac_role_permissions')
        db.create_table(m2m_table_name, (
            ('id', models.AutoField(verbose_name='ID', primary_key=True, auto_created=True)),
            ('role', models.ForeignKey(orm['rbac.role'], null=False)),
            ('permission', models.ForeignKey(orm['rbac.permission'], null=False))
        ))
        db.create_unique(m2m_table_name, ['role_id', 'permission_id'])

        # Adding model 'RoleParent'
        db.create_table('rbac_roleparent', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('parent', self.gf('django.db.models.fields.related.ForeignKey')(related_name='+', to=orm['rbac.Role'])),
            ('role', self.gf('django.db.models.fields.related.ForeignKey')(related_name='+', to=orm['rbac.Role'])),
        ))
        db.send_create_signal('rbac', ['RoleParent'])

        # Adding unique constraint on 'RoleParent', fields ['parent', 'role']
        db.create_unique('rbac_roleparent', ['parent_id', 'role_id'])

        # Adding model 'UserRole'
        db.create_table('rbac_userrole', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('content_type', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['contenttypes.ContentType'])),
            ('object_id', self.gf('django.db.models.fields.PositiveIntegerField')()),
            ('role', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['rbac.Role'])),
            ('date_from', self.gf('django.db.models.fields.DateField')(null=True, blank=True)),
            ('date_to', self.gf('django.db.models.fields.DateField')(null=True, blank=True)),
        ))
        db.send_create_signal('rbac', ['UserRole'])

    def backwards(self, orm):
        # Removing unique constraint on 'RoleParent', fields ['parent', 'role']
        db.delete_unique('rbac_roleparent', ['parent_id', 'role_id'])

        # Deleting model 'Permission'
        db.delete_table('rbac_permission')

        # Deleting model 'Role'
        db.delete_table('rbac_role')

        # Removing M2M table for field permissions on 'Role'
        db.delete_table(db.shorten_name('rbac_role_permissions'))

        # Deleting model 'RoleParent'
        db.delete_table('rbac_roleparent')

        # Deleting model 'UserRole'
        db.delete_table('rbac_userrole')

    models = {
        'contenttypes.contenttype': {
            'Meta': {'ordering': "('name',)", 'unique_together': "(('app_label', 'model'),)", 'object_name': 'ContentType', 'db_table': "'django_content_type'"},
            'app_label': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'model': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100'})
        },
        'rbac.permission': {
            'Meta': {'object_name': 'Permission'},
            'description': ('django.db.models.fields.TextField', [], {'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '100', 'db_index': 'True'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '200', 'unique': 'True', 'null': 'True', 'blank': 'True'})
        },
        'rbac.role': {
            'Meta': {'object_name': 'Role'},
            'description': ('django.db.models.fields.TextField', [], {'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '300', 'db_index': 'True'}),
            'permissions': ('django.db.models.fields.related.ManyToManyField', [], {'related_name': "'roles'", 'symmetrical': 'False', 'to': "orm['rbac.Permission']"})
        },
        'rbac.roleparent': {
            'Meta': {'unique_together': "(('parent', 'role'),)", 'object_name': 'RoleParent'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'parent': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'+'", 'to': "orm['rbac.Role']"}),
            'role': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'+'", 'to': "orm['rbac.Role']"})
        },
        'rbac.userrole': {
            'Meta': {'object_name': 'UserRole'},
            'content_type': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['contenttypes.ContentType']"}),
            'date_from': ('django.db.models.fields.DateField', [], {'null': 'True', 'blank': 'True'}),
            'date_to': ('django.db.models.fields.DateField', [], {'null': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'object_id': ('django.db.models.fields.PositiveIntegerField', [], {}),
            'role': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['rbac.Role']"})
        }
    }

    complete_apps = ['rbac']
